@@ -1,12 +1,9 @@
+package SVN::Hooks::CheckJira;
+# ABSTRACT: Integrate Subversion with the JIRA ticketing system.
+$SVN::Hooks::CheckJira::VERSION = '1.31';
 use strict;
 use warnings;
 
-package SVN::Hooks::CheckJira;
-{
-  $SVN::Hooks::CheckJira::VERSION = '1.26';
-}
-# ABSTRACT: Integrate Subversion with the JIRA ticketing system.
-
 use Carp;
 use Data::Util qw(:check);
 use SVN::Hooks;
@@ -39,7 +36,7 @@ sub CHECK_JIRA_CONFIG {
     if (defined $MatchLog) {
 	is_rx($MatchLog) or croak "CHECK_JIRA_CONFIG: fourth argument must be a Regexp.\n";
     } else {
-	$MatchLog = qr/[A-Z]{2,}/;
+	$MatchLog = qr/(.*)/;
     }
 
     @_ >= 3 && @_ <= 5
@@ -251,7 +248,7 @@ SVN::Hooks::CheckJira - Integrate Subversion with the JIRA ticketing system.
 
 =head1 VERSION
 
-version 1.26
+version 1.31
 
 =head1 DESCRIPTION
 
@@ -478,7 +475,7 @@ Gustavo L. de M. Chaves <gnustavo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by CPqD.
+This software is copyright (c) 2015 by CPqD <www.cpqd.com.br>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
